@@ -1,9 +1,7 @@
 from typing import List
 from functools import reduce
-from statistics import mean
-
-
-def _flatten(values: list): return list(reduce(lambda x, y: x + (y if isinstance(y, list) else [y]), values, []))
+from datetime import datetime
+from hestia_earth.utils.tools import list_average, safe_parse_date
 
 
 def _next_error(values: list): return next((x for x in values if x is not True), True)
@@ -14,7 +12,7 @@ def _filter_list_errors(values: list, return_single=True):
     return True if return_single and len(values) == 0 else (values[0] if return_single and len(values) == 1 else values)
 
 
-def _update_error_path(error: dict, key: str, index=None):
+def update_error_path(error: dict, key: str, index=None):
     path = f".{key}[{index}]{error.get('dataPath')}" if index is not None else f".{key}{error.get('dataPath')}"
     return {**error, **{'dataPath': path}}
 
@@ -65,16 +63,16 @@ def _same_properties(value: dict, props: List[str]):
     return identical
 
 
-def _average(value, default=0): return mean(value) if value is not None and isinstance(value, list) else default
-
-
 def _value_average(node: dict, default=0):
     value = node.get('value')
     is_number = value is not None and (isinstance(value, float) or isinstance(value, int))
-    return value if is_number else _average(value, default)
+    return value if is_number else list_average(value, default)
 
 
 def _find_linked_node(nodes: list, linked_node: dict):
     type = linked_node.get('type')
     id = linked_node.get('id')
     return next((node for node in nodes if node['type'] == type and node['id'] == id), None) if type and id else None
+
+
+def _is_before_today(date: str): return safe_parse_date(date).date() < datetime.now().date()
