@@ -1,10 +1,14 @@
 from hestia_earth.schema import SchemaType, CycleFunctionalUnitMeasure, SiteSiteType, TermTermType
+from hestia_earth.utils.tools import flatten
 from hestia_earth.utils.date import diff_in_days, is_in_days
 from hestia_earth.utils.api import find_node
 
-from hestia_earth.validation.utils import _flatten, _find_linked_node, _value_average, _list_sum_terms
-from .shared import validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max
-from .shared import validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length
+from hestia_earth.validation.utils import _find_linked_node, _value_average, _list_sum_terms
+from .shared import (
+    validate_dates, validate_list_dates, validate_date_lt_today, validate_list_duplicates, validate_list_min_max,
+    validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
+    validate_properties_default_value
+)
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
 from .product import validate_economicValueShare, validate_value as validate_product_value
 from .data_completeness import validate_dataCompleteness
@@ -106,16 +110,19 @@ def validate_cycle(cycle: dict, nodes=[]):
         The list of errors for the `Cycle`, which can be empty if no errors detected.
     """
     site = _find_linked_node(nodes, cycle.get('site', {}))
-    return _flatten([
+    return flatten([
         validate_cycle_dates(cycle),
+        validate_date_lt_today(cycle, 'startDate'),
+        validate_date_lt_today(cycle, 'endDate'),
         validate_linked_source_privacy(cycle, 'defaultSource', nodes),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
         validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True
-    ]) + _flatten([
+    ]) + flatten([
         validate_list_dates(cycle, 'emissions'),
         validate_list_min_max(cycle, 'emissions'),
         validate_list_term_percent(cycle, 'emissions'),
         validate_list_dates_length(cycle, 'emissions'),
+        validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
         validate_list_duplicates(cycle, 'emissions', [
             'term.@id',
             'inputs.@id',
@@ -125,9 +132,11 @@ def validate_cycle(cycle: dict, nodes=[]):
             'startDate',
             'endDate',
             'dates'
-        ])
-    ] if len(cycle.get('emissions', [])) > 0 else []) + _flatten([
+        ]),
+        validate_properties_default_value(cycle, 'emissions', 'properties')
+    ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
         validate_list_dates_length(cycle, 'inputs'),
+        validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'inputs'),
         validate_list_term_percent(cycle, 'inputs'),
         validate_list_duplicates(cycle, 'inputs', [
@@ -138,24 +147,30 @@ def validate_cycle(cycle: dict, nodes=[]):
             'startDate',
             'endDate',
             'dates'
-        ])
-    ] if len(cycle.get('inputs', [])) > 0 else []) + _flatten([
+        ]),
+        validate_properties_default_value(cycle, 'inputs', 'properties')
+    ] if len(cycle.get('inputs', [])) > 0 else []) + flatten([
         validate_list_dates_length(cycle, 'products'),
+        validate_list_date_lt_today(cycle, 'products', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'products'),
         validate_list_term_percent(cycle, 'products'),
         validate_economicValueShare(cycle.get('products')),
         validate_sum_aboveGroundCropResidue(cycle.get('products')),
         validate_product_value(cycle.get('products')),
+        validate_properties_default_value(cycle, 'products', 'properties'),
         validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True
-    ] if len(cycle.get('products', [])) > 0 else []) + _flatten([
+    ] if len(cycle.get('products', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'practices'),
+        validate_list_date_lt_today(cycle, 'practices', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'practices'),
         validate_list_term_percent(cycle, 'practices'),
         validate_cropResidueManagement(cycle.get('practices')),
-        validate_longFallowPeriod(cycle.get('practices'))
-    ] if len(cycle.get('practices', [])) > 0 else []) + _flatten([
+        validate_longFallowPeriod(cycle.get('practices')),
+        validate_properties_default_value(cycle, 'practices', 'properties')
+    ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnitMeasure(cycle, site)
-    ] if 'functionalUnitMeasure' in cycle and site else []) + _flatten([
+    ] if 'functionalUnitMeasure' in cycle and site else []) + flatten([
+        validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
         validate_previous_transformation(cycle.get('transformations')),
         validate_list_duplicates(cycle, 'transformations', [
             'term.@id'
