@@ -1,10 +1,9 @@
 from functools import reduce
 from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
-from hestia_earth.utils.tools import non_empty_list, safe_parse_float
+from hestia_earth.utils.tools import non_empty_list, safe_parse_float, flatten
 
-from hestia_earth.validation.utils import _flatten, _filter_list_errors, _list_has_props, _value_range_error, \
-    _value_average
+from hestia_earth.validation.utils import _filter_list_errors, _list_has_props, _value_range_error, _value_average
 
 
 SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
@@ -53,7 +52,7 @@ def _validate_soilTexture_percent(lookup):
 
     def validate_all(measurements: list):
         values = list(filter(lambda v: v['term']['@id'] in soil_texture_ids, measurements))
-        return len(values) == 0 or _flatten(map(
+        return len(values) == 0 or flatten(map(
             lambda measurement: list(map(lambda id: validate_single(measurements, measurement, id), SOIL_TEXTURE_IDS)),
             values
         ))
@@ -78,7 +77,7 @@ def validate_soilTexture(measurements: list):
     groupped_measurements = _group_measurements_depth(measurements).values()
     results_sum = list(map(_validate_soiltTexture_sum, groupped_measurements))
     valid_sum = next((x for x in results_sum if x is not True), True)
-    results_percent = _flatten(map(_validate_soilTexture_percent(soilTexture), groupped_measurements))
+    results_percent = flatten(map(_validate_soilTexture_percent(soilTexture), groupped_measurements))
     valid_percent = next((x for x in results_percent if x is not True), True)
     return valid_sum if valid_sum is not True else valid_percent
 
