@@ -1,6 +1,7 @@
-from .shared import validate_dates, validate_region, validate_country, \
-    need_validate_coordinates, validate_coordinates, \
-    validate_area, need_validate_area
+from .shared import (
+    validate_dates, validate_region, validate_country, need_validate_coordinates, validate_coordinates,
+    validate_area, need_validate_area, validate_date_lt_today
+)
 
 
 def validate_organisation_dates(organisation: dict):
@@ -29,6 +30,8 @@ def validate_organisation(organisation: dict, nodes=[]):
     """
     return [
         validate_organisation_dates(organisation),
+        validate_date_lt_today(organisation, 'startDate'),
+        validate_date_lt_today(organisation, 'endDate'),
         validate_country(organisation) if 'country' in organisation else True,
         validate_region(organisation) if 'region' in organisation else True,
         validate_coordinates(organisation) if need_validate_coordinates(organisation) else True,
