@@ -1,10 +1,35 @@
 from typing import List
 import re
+from hestia_earth.utils.tools import flatten, safe_parse_float
+from hestia_earth.utils.api import download_hestia
+from hestia_earth.utils.model import find_term_match
 
-from hestia_earth.validation.geojson import _get_geojson_area
-from hestia_earth.validation.gee import _get_region_id
-from hestia_earth.validation.utils import _filter_list_errors, _next_error, _same_properties, _value_average
-from hestia_earth.validation.utils import _find_linked_node, _list_has_props
+from hestia_earth.validation.geojson import get_geojson_area
+from hestia_earth.validation.gee import is_enabled, get_region_id
+from hestia_earth.validation.utils import (
+    update_error_path, _filter_list_errors, _next_error, _same_properties, _value_average,
+    _find_linked_node, _list_has_props, _is_before_today
+)
+
+
+def validate_date_lt_today(node: dict, key: str):
+    return node.get(key) is None or _is_before_today(node.get(key)) or {
+        'level': 'error',
+        'dataPath': f".{key}",
+        'message': "must be lower than today's date"
+    }
+
+
+def validate_list_date_lt_today(node: dict, list_key: str, node_keys: list):
+    def validate(values):
+        index = values[0]
+        value = values[1]
+        errors = list(map(lambda key: {'key': key, 'error': validate_date_lt_today(value, key)}, node_keys))
+        return _filter_list_errors(
+            [update_error_path(error['error'], list_key, index) for error in errors if error['error'] is not True]
+        )
+
+    return _filter_list_errors(flatten(map(validate, enumerate(node.get(list_key, [])))))
 
 
 def validate_dates(node: dict):
@@ -59,8 +84,14 @@ def validate_list_min_max(node: dict, list_key: str):
         index = values[0]
         min = value.get('min', 0)
         max = value.get('max', 0)
+        skip_compare = (
+            isinstance(min, list) and not isinstance(max, list)
+        ) or (
+            isinstance(max, list) and not isinstance(min, list)
+        )
         compare_lists = isinstance(min, list) and isinstance(max, list)
-        is_valid = _compare_list_min_max(min, max) if compare_lists else _compare_min_max(min, max)
+        is_valid = True if skip_compare else \
+            _compare_list_min_max(min, max) if compare_lists else _compare_min_max(min, max)
         return is_valid is True or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].max",
@@ -134,7 +165,7 @@ def validate_country(node: dict):
     }
 
 
-def need_validate_coordinates(node: dict): return 'latitude' in node and 'longitude' in node
+def need_validate_coordinates(node: dict): return is_enabled() and 'latitude' in node and 'longitude' in node
 
 
 def validate_coordinates(node: dict, region_key='region'):
@@ -143,7 +174,7 @@ def validate_coordinates(node: dict, region_key='region'):
     country = node.get('country', {})
     region = node.get(region_key)
     gadm_id = region.get('@id') if region else country.get('@id')
-    id = _get_region_id(gadm_id, latitude=latitude, longitude=longitude)
+    id = get_region_id(gadm_id, latitude=latitude, longitude=longitude)
     return gadm_id == id or {
         'level': 'error',
         'dataPath': f".{region_key}" if region else '.country',
@@ -159,7 +190,7 @@ def need_validate_area(node: dict): return 'area' in node and 'boundary' in node
 
 def validate_area(node: dict):
     try:
-        area = _get_geojson_area(node.get('boundary'))
+        area = get_geojson_area(node.get('boundary'))
         return area == round(node.get('area'), 1) or {
             'level': 'error',
             'dataPath': '.area',
@@ -210,3 +241,41 @@ def validate_linked_source_privacy(node: dict, key: str, nodes: list):
             }
         }
     }
+
+
+def _property_default_value(term_id: str, property: dict):
+    # load the term defaultProperties and find the matching property
+    term = download_hestia(term_id)
+    return safe_parse_float(
+        find_term_match(term.get('defaultProperties', []), property.get('term', {}).get('@id')).get('value')
+    )
+
+
+def validate_properties_default_value(node: dict, list_key: str, properties_key: str):
+    def validate_properties(term_id: str, values: list):
+        index = values[0]
+        prop = values[1]
+        value = safe_parse_float(prop.get('value'))
+        default_value = _property_default_value(term_id, prop)
+        delta = abs(100 - value / default_value * 100) if default_value > 0 else 0
+        return delta < 25 or {
+            'level': 'warning',
+            'dataPath': f".{properties_key}[{index}].value",
+            'message': 'should be within 25% of default value',
+            'params': {
+                'current': value,
+                'default': default_value,
+                'delta': round(delta, 2)
+            }
+        }
+
+    def validate_nodes(values):
+        index = values[0]
+        value = values[1]
+        term_id = value.get('term', {}).get('@id')
+        errors = _filter_list_errors(
+            flatten(map(lambda v: validate_properties(term_id, v), enumerate(value.get(properties_key, [])))), False
+        )
+        return [update_error_path(error, list_key, index) for error in errors]
+
+    return _filter_list_errors(flatten(map(validate_nodes, enumerate(node.get(list_key, [])))))
