@@ -1,10 +1,13 @@
 from hestia_earth.schema import SiteSiteType
+from hestia_earth.utils.tools import flatten
 
-from hestia_earth.validation.utils import _flatten
-from hestia_earth.validation.gee import _fetch_data
-from .shared import validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max
-from .shared import validate_region, validate_country, validate_coordinates, need_validate_coordinates
-from .shared import validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy
+from hestia_earth.validation.gee import is_enabled, fetch_data
+from .shared import (
+    validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max,
+    validate_region, validate_country, validate_coordinates, need_validate_coordinates,
+    validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
+    validate_list_date_lt_today, validate_date_lt_today, validate_properties_default_value
+)
 from .infrastructure import validate_lifespan
 from .measurement import validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
@@ -14,7 +17,8 @@ INLAND_TYPES = [
     SiteSiteType.CROPLAND.value,
     SiteSiteType.PERMANENT_PASTURE.value,
     SiteSiteType.POND.value,
-    SiteSiteType.BUILDING.value,
+    SiteSiteType.ANIMAL_HOUSING.value,
+    SiteSiteType.FACTORY.value,
     SiteSiteType.FOREST.value,
     SiteSiteType.OTHER_NATURAL_VEGETATION.value
 ]
@@ -43,12 +47,12 @@ def validate_siteType(site: dict):
     values_str = ', '.join(map(lambda v: str(v), values))
 
     def validate():
-        value = _fetch_data(collection='MODIS/006/MCD12Q1',
-                            ee_type='raster_by_period',
-                            band_name='LC_Prop2',
-                            year='2019',
-                            latitude=site.get('latitude'),
-                            longitude=site.get('longitude')).get('mean')
+        value = fetch_data(collection='MODIS/006/MCD12Q1',
+                           ee_type='raster_by_period',
+                           band_name='LC_Prop2',
+                           year='2019',
+                           latitude=site.get('latitude'),
+                           longitude=site.get('longitude')).get('mean')
         return value in values
 
     return len(values) == 0 or validate() or {
@@ -80,14 +84,17 @@ def validate_site(site: dict, nodes=[]):
     """
     return [
         validate_site_dates(site),
+        validate_date_lt_today(site, 'startDate'),
+        validate_date_lt_today(site, 'endDate'),
         validate_linked_source_privacy(site, 'defaultSource', nodes),
         validate_siteType(site) if need_validate_coordinates(site) else True,
-        validate_country(site) if 'country' in site else True,
-        validate_region(site) if 'region' in site else True,
+        validate_country(site) if is_enabled() and 'country' in site else True,
+        validate_region(site) if is_enabled() and 'region' in site else True,
         validate_coordinates(site) if validate_site_coordinates(site) else True,
         validate_area(site) if need_validate_area(site) else True
-    ] + _flatten([
+    ] + flatten([
         validate_list_dates(site, 'measurements'),
+        validate_list_date_lt_today(site, 'measurements', ['startDate', 'endDate']),
         validate_list_min_max(site, 'measurements'),
         validate_list_term_percent(site, 'measurements'),
         validate_soilTexture(site.get('measurements')),
@@ -102,14 +109,18 @@ def validate_site(site: dict, nodes=[]):
             'depthUpper',
             'depthLower'
         ]),
-        validate_term_unique(site.get('measurements'))
-    ] if 'measurements' in site else []) + _flatten([
+        validate_term_unique(site.get('measurements')),
+        validate_properties_default_value(site, 'measurements', 'properties')
+    ] if 'measurements' in site else []) + flatten([
         validate_list_dates(site, 'infrastructure'),
+        validate_list_date_lt_today(site, 'infrastructure', ['startDate', 'endDate']),
         validate_lifespan(site.get('infrastructure'))
-    ] if 'infrastructure' in site else []) + _flatten([
+    ] if 'infrastructure' in site else []) + flatten([
         validate_list_dates(site, 'practices'),
+        validate_list_date_lt_today(site, 'practices', ['startDate', 'endDate']),
         validate_list_min_max(site, 'practices'),
         validate_list_term_percent(site, 'practices'),
         validate_cropResidueManagement(site.get('practices')),
-        validate_longFallowPeriod(site.get('practices'))
+        validate_longFallowPeriod(site.get('practices')),
+        validate_properties_default_value(site, 'practices', 'properties')
     ] if 'practices' in site else [])
