@@ -5,6 +5,9 @@ from hestia_earth.validation.validators.practice import validate_cropResidueMana
 
 
 def test_validate_cropResidueManagement_valid():
+    # no practices should be valid
+    assert validate_cropResidueManagement([])
+
     with open(f"{fixtures_path}/practice/cropResidueManagement/valid.json") as f:
         data = json.load(f)
     assert validate_cropResidueManagement(data.get('nodes'))
@@ -24,6 +27,9 @@ def test_validate_cropResidueManagement_invalid():
 
 
 def test_validate_longFallowPeriod_valid():
+    # no practices should be valid
+    assert validate_longFallowPeriod([])
+
     with open(f"{fixtures_path}/practice/longFallowPeriod/valid.json") as f:
         data = json.load(f)
     assert validate_longFallowPeriod(data.get('nodes'))
