@@ -7,6 +7,9 @@ fixtures_folder = f"{fixtures_path}/transformation"
 
 
 def test_validate_previous_transformation_valid():
+    # no transformations should be valid
+    assert validate_previous_transformation([])
+
     with open(f"{fixtures_folder}/previousTransformationTerm/valid.json") as f:
         data = json.load(f)
     assert validate_previous_transformation(data.get('nodes'))
